@@ -224,6 +224,9 @@ gesture_unregister_point (ClutterGestureAction *action, gint position)
 {
   ClutterGestureActionPrivate *priv = action->priv;
 
+  if (action->priv->points->len == 0)
+    return;
+
   g_array_remove_index (priv->points, position);
 }
 
@@ -352,8 +355,8 @@ begin_gesture (ClutterGestureAction *action,
 }
 
 static gboolean
-stage_captured_event_cb (ClutterActor       *stage,
-                         ClutterEvent       *event,
+stage_captured_event_cb (ClutterActor         *stage,
+                         ClutterEvent         *event,
                          ClutterGestureAction *action)
 {
   ClutterGestureActionPrivate *priv = action->priv;
@@ -362,6 +365,20 @@ stage_captured_event_cb (ClutterActor       *stage,
   float threshold_x, threshold_y;
   gboolean return_value;
   GesturePoint *point;
+  ClutterEventType event_type;
+
+  event_type = clutter_event_type (event);
+  if (event_type != CLUTTER_TOUCH_CANCEL &&
+      event_type != CLUTTER_TOUCH_UPDATE &&
+      event_type != CLUTTER_TOUCH_END &&
+      event_type != CLUTTER_MOTION &&
+      event_type != CLUTTER_BUTTON_RELEASE)
+    return CLUTTER_EVENT_PROPAGATE;
+
+  if (event->type != CLUTTER_TOUCH_CANCEL &&
+      event->type != CLUTTER_TOUCH_UPDATE && event->type != CLUTTER_TOUCH_END &&
+      event->type != CLUTTER_MOTION && event->type != CLUTTER_BUTTON_RELEASE)
+    return CLUTTER_EVENT_PROPAGATE;
 
   if ((point = gesture_find_point (action, event, &position)) == NULL)
     return CLUTTER_EVENT_PROPAGATE;
@@ -471,7 +488,7 @@ stage_captured_event_cb (ClutterActor       *stage,
       break;
     }
 
-  if (priv->points->len == 0)
+  if (priv->points->len == 0 && priv->stage_capture_id)
     {
       g_signal_handler_disconnect (priv->stage, priv->stage_capture_id);
       priv->stage_capture_id = 0;
