@@ -48,7 +48,6 @@
 #endif
 
 /* sadly, we are still using ClutterShader internally */
-#define COGL_DISABLE_DEPRECATION_WARNINGS
 #define CLUTTER_DISABLE_DEPRECATION_WARNINGS
 
 /* This file depends on the glib enum types which aren't exposed
@@ -2515,13 +2514,8 @@ fbo_source_queue_relayout_cb (ClutterActor *source,
  *
  * Some tips on usage:
  *
- * <itemizedlist>
- *   <listitem>
- *     <para>The source actor must be made visible (i.e by calling
- *     #clutter_actor_show).</para>
- *   </listitem>
- *   <listitem>
- *     <para>The source actor must have a parent in order for it to be
+ *   - The source actor must be visible
+ *   - The source actor must have a parent in order for it to be
  *     allocated a size from the layouting mechanism. If the source
  *     actor does not have a parent when this function is called then
  *     the ClutterTexture will adopt it and allocate it at its
@@ -2530,10 +2524,8 @@ fbo_source_queue_relayout_cb (ClutterActor *source,
  *     intend to display the source actor then you must make sure that
  *     the actor is parented before calling
  *     clutter_texture_new_from_actor() or that you unparent it before
- *     adding it to a container.</para>
- *   </listitem>
- *   <listitem>
- *     <para>When getting the image for the clone texture, Clutter
+ *     adding it to a container.
+ *   - When getting the image for the clone texture, Clutter
  *     will attempt to render the source actor exactly as it would
  *     appear if it was rendered on screen. The source actor's parent
  *     transformations are taken into account. Therefore if your
@@ -2545,33 +2537,21 @@ fbo_source_queue_relayout_cb (ClutterActor *source,
  *     actor will be projected as if a small section of the screen was
  *     being viewed. Before version 0.8.2, an orthogonal identity
  *     projection was used which meant that the source actor would be
- *     clipped if any part of it was not on the zero Z-plane.</para>
- *   </listitem>
- *   <listitem>
- *     <para>Avoid reparenting the source with the created texture.</para>
- *   </listitem>
- *   <listitem>
- *     <para>A group can be padded with a transparent rectangle as to
+ *     clipped if any part of it was not on the zero Z-plane.
+ *   - Avoid reparenting the source with the created texture.
+ *   - A group can be padded with a transparent rectangle as to
  *     provide a border to contents for shader output (blurring text
- *     for example).</para>
- *   </listitem>
- *   <listitem>
- *     <para>The texture will automatically resize to contain a further
+ *     for example).
+ *   - The texture will automatically resize to contain a further
  *     transformed source. However, this involves overhead and can be
  *     avoided by placing the source actor in a bounding group
- *     sized large enough to contain any child tranformations.</para>
- *   </listitem>
- *   <listitem>
- *     <para>Uploading pixel data to the texture (e.g by using
+ *     sized large enough to contain any child tranformations.
+ *   -  Uploading pixel data to the texture (e.g by using
  *     clutter_texture_set_from_file()) will destroy the offscreen texture
- *     data and end redirection.</para>
- *   </listitem>
- *   <listitem>
- *     <para>cogl_texture_get_data() with the handle returned by
+ *     data and end redirection.
+ *   - cogl_texture_get_data() with the handle returned by
  *     clutter_texture_get_cogl_texture() can be used to read the
  *     offscreen texture pixels into a pixbuf.</para>
- *   </listitem>
- * </itemizedlist>
  *
  * Return value: A newly created #ClutterTexture object, or %NULL on failure.
  *
