@@ -1,9 +1,7 @@
 #include <clutter/clutter.h>
-#include "test-conform-common.h"
 
-void
-actor_add_child (TestConformSimpleFixture *fixture,
-                 gconstpointer dummy)
+static void
+actor_add_child (void)
 {
   ClutterActor *actor = clutter_actor_new ();
   ClutterActor *iter;
@@ -49,9 +47,8 @@ actor_add_child (TestConformSimpleFixture *fixture,
   g_assert (actor == NULL);
 }
 
-void
-actor_insert_child (TestConformSimpleFixture *fixture,
-                    gconstpointer data)
+static void
+actor_insert_child (void)
 {
   ClutterActor *actor = clutter_actor_new ();
   ClutterActor *iter;
@@ -137,9 +134,8 @@ actor_insert_child (TestConformSimpleFixture *fixture,
   g_assert (actor == NULL);
 }
 
-void
-actor_remove_child (TestConformSimpleFixture *fixture,
-                    gconstpointer data)
+static void
+actor_remove_child (void)
 {
   ClutterActor *actor = clutter_actor_new ();
   ClutterActor *iter;
@@ -182,9 +178,8 @@ actor_remove_child (TestConformSimpleFixture *fixture,
   g_assert (actor == NULL);
 }
 
-void
-actor_raise_child (TestConformSimpleFixture *fixture,
-                   gconstpointer dummy)
+static void
+actor_raise_child (void)
 {
   ClutterActor *actor = clutter_actor_new ();
   ClutterActor *iter;
@@ -249,9 +244,8 @@ actor_raise_child (TestConformSimpleFixture *fixture,
   g_assert (iter == NULL);
 }
 
-void
-actor_lower_child (TestConformSimpleFixture *fixture,
-                   gconstpointer dummy)
+static void
+actor_lower_child (void)
 {
   ClutterActor *actor = clutter_actor_new ();
   ClutterActor *iter;
@@ -314,9 +308,8 @@ actor_lower_child (TestConformSimpleFixture *fixture,
   g_assert (actor == NULL);
 }
 
-void
-actor_replace_child (TestConformSimpleFixture *fixture,
-                     gconstpointer dummy)
+static void
+actor_replace_child (void)
 {
   ClutterActor *actor = clutter_actor_new ();
   ClutterActor *iter;
@@ -375,9 +368,8 @@ actor_replace_child (TestConformSimpleFixture *fixture,
   g_assert (actor == NULL);
 }
 
-void
-actor_remove_all (TestConformSimpleFixture *fixture,
-                  gconstpointer dummy)
+static void
+actor_remove_all (void)
 {
   ClutterActor *actor = clutter_actor_new ();
 
@@ -436,9 +428,8 @@ actor_removed (ClutterContainer *container,
   *counter += 1;
 }
 
-void
-actor_container_signals (TestConformSimpleFixture *fixture G_GNUC_UNUSED,
-                         gconstpointer data G_GNUC_UNUSED)
+static void
+actor_container_signals (void)
 {
   ClutterActor *actor = clutter_actor_new ();
   int add_count, remove_count;
@@ -478,3 +469,81 @@ actor_container_signals (TestConformSimpleFixture *fixture G_GNUC_UNUSED,
   clutter_actor_destroy (actor);
   g_assert (actor == NULL);
 }
+
+static void
+actor_contains (void)
+{
+  /* This build up the following tree:
+   *
+   *              a
+   *          ╱   │   ╲
+   *         ╱    │    ╲
+   *        b     c     d
+   *       ╱ ╲   ╱ ╲   ╱ ╲
+   *      e   f g   h i   j
+   */
+  struct {
+    ClutterActor *actor_a, *actor_b, *actor_c, *actor_d, *actor_e;
+    ClutterActor *actor_f, *actor_g, *actor_h, *actor_i, *actor_j;
+  } d;
+  int x, y;
+  ClutterActor **actor_array = &d.actor_a;
+
+  /* Matrix of expected results */
+  static const gboolean expected_results[] =
+    {         /* a, b, c, d, e, f, g, h, i, j */
+      /* a */    1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+      /* b */    0, 1, 0, 0, 1, 1, 0, 0, 0, 0,
+      /* c */    0, 0, 1, 0, 0, 0, 1, 1, 0, 0,
+      /* d */    0, 0, 0, 1, 0, 0, 0, 0, 1, 1,
+      /* e */    0, 0, 0, 0, 1, 0, 0, 0, 0, 0,
+      /* f */    0, 0, 0, 0, 0, 1, 0, 0, 0, 0,
+      /* g */    0, 0, 0, 0, 0, 0, 1, 0, 0, 0,
+      /* h */    0, 0, 0, 0, 0, 0, 0, 1, 0, 0,
+      /* i */    0, 0, 0, 0, 0, 0, 0, 0, 1, 0,
+      /* j */    0, 0, 0, 0, 0, 0, 0, 0, 0, 1
+    };
+
+  d.actor_a = clutter_actor_new ();
+  d.actor_b = clutter_actor_new ();
+  d.actor_c = clutter_actor_new ();
+  d.actor_d = clutter_actor_new ();
+  d.actor_e = clutter_actor_new ();
+  d.actor_f = clutter_actor_new ();
+  d.actor_g = clutter_actor_new ();
+  d.actor_h = clutter_actor_new ();
+  d.actor_i = clutter_actor_new ();
+  d.actor_j = clutter_actor_new ();
+
+  clutter_actor_add_child (d.actor_a, d.actor_b);
+  clutter_actor_add_child (d.actor_a, d.actor_c);
+  clutter_actor_add_child (d.actor_a, d.actor_d);
+
+  clutter_actor_add_child (d.actor_b, d.actor_e);
+  clutter_actor_add_child (d.actor_b, d.actor_f);
+
+  clutter_actor_add_child (d.actor_c, d.actor_g);
+  clutter_actor_add_child (d.actor_c, d.actor_h);
+
+  clutter_actor_add_child (d.actor_d, d.actor_i);
+  clutter_actor_add_child (d.actor_d, d.actor_j);
+
+  for (y = 0; y < 10; y++)
+    for (x = 0; x < 10; x++)
+      g_assert_cmpint (clutter_actor_contains (actor_array[x],
+                                               actor_array[y]),
+                       ==,
+                       expected_results[x * 10 + y]);
+}
+
+CLUTTER_TEST_SUITE (
+  CLUTTER_TEST_UNIT ("/actor/graph/add-child", actor_add_child)
+  CLUTTER_TEST_UNIT ("/actor/graph/insert-child", actor_insert_child)
+  CLUTTER_TEST_UNIT ("/actor/graph/remove-child", actor_remove_child)
+  CLUTTER_TEST_UNIT ("/actor/graph/raise-child", actor_raise_child)
+  CLUTTER_TEST_UNIT ("/actor/graph/lower-child", actor_lower_child)
+  CLUTTER_TEST_UNIT ("/actor/graph/replace-child", actor_replace_child)
+  CLUTTER_TEST_UNIT ("/actor/graph/remove-all", actor_remove_all)
+  CLUTTER_TEST_UNIT ("/actor/graph/container-signals", actor_container_signals)
+  CLUTTER_TEST_UNIT ("/actor/graph/contains", actor_contains)
+)
